/*
 * Copyright (c) 2003-2017, Parallels International GmbH
 * Copyright (c) 2017-2019 Virtuozzo International GmbH. All rights reserved.
 *
 * This file is part of OpenVZ. OpenVZ is free software;
 * you can redistribute it and/or modify it under the terms of the GNU
 * General Public License as published by the Free Software Foundation;
 * either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 *
 * Our contact details: Virtuozzo International GmbH, Vordergasse 59, 8200
 * Schaffhausen, Switzerland.
 */

#include <stdio.h>
#include <string.h>

#include "vzparsecpu.h"

#define PROC_VZ_SLM	"/proc/slm/groups/%lu/info"


int parse_slm_info(unsigned long veid, struct slm_info *info)
{
	struct slm_info_res *res = NULL;
	char fname[256];
	char buf[128];
	unsigned long val;
	FILE *fp;

	int n = snprintf(fname, sizeof(fname), PROC_VZ_SLM, veid);
	if (n < 0 || n >= (int)sizeof(fname))
		return -1;

	if ((fp = fopen(fname, "rt")) == NULL)
		return -1;
	memset(info, 0, sizeof(struct slm_info));
	while (fgets(buf, sizeof(buf), fp) != NULL) {
		if (!strncmp("Resource: memory", buf, 16)) {
			res = &info->mem;
		} else if (!strncmp("Resource: lowmem", buf, 16)) {
			res = &info->lowmem;
		} else if (sscanf(buf, "|\t|\tQuality: %lu", &val) == 1) {
			res->quality = val;
		} else if (sscanf(buf, "|\t|\tInst_cap: %lu", &val) == 1) {
			res->inst_cap = val;
		} else if (sscanf(buf, "|\t|\tAvg_cap: %lu", &val) == 1) {
			res->avg_cap = val;
		} else if (sscanf(buf, "|\t|\tInst_usage: %lu", &val) == 1) {
			res->inst_usage = val;
		} else if (sscanf(buf, "|\t|\tAvg_usage: %lu", &val) == 1) {
			res->avg_usage = val;
		} else if (sscanf(buf, "|\t|\tLimit: %lu", &val) == 1) {
			res->limit = val;
		}
	}
	fclose(fp);
	return 0;
}
